==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d3/dda/group__widget_8h.js <==
var group__widget_8h =
[
    [ "GroupListWidgets", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2", [
      [ "WID_GL_CAPTION", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a78f7723009fbf2529da1f19aac80540b", null ],
      [ "WID_GL_SORT_BY_ORDER", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a41128bb986ab09b10e0efe6991932b94", null ],
      [ "WID_GL_SORT_BY_DROPDOWN", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2acc24cc454d4e8db0d41644db6b9f5191", null ],
      [ "WID_GL_LIST_VEHICLE", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2acf25aceb2004acb11b6fa7ce8e1f72b2", null ],
      [ "WID_GL_LIST_VEHICLE_SCROLLBAR", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2abffb4627acd874d536908638fa637711", null ],
      [ "WID_GL_AVAILABLE_VEHICLES", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2aa606555b2be516d207db39dfd4140954", null ],
      [ "WID_GL_MANAGE_VEHICLES_DROPDOWN", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a19363c4697c75ed08a99e2bb934fec53", null ],
      [ "WID_GL_STOP_ALL", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a0609e86d4eeba508ebeaa2aa7e400687", null ],
      [ "WID_GL_START_ALL", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a91fc2a0a141f751551fe4850ff133900", null ],
      [ "WID_GL_ALL_VEHICLES", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a9802f55644a76c6ec5893f35a06300f2", null ],
      [ "WID_GL_DEFAULT_VEHICLES", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2aff47fca9215d425c5276f87c32dec6d7", null ],
      [ "WID_GL_LIST_GROUP", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a0433e02dfa7abb45b0f658bc8396ca60", null ],
      [ "WID_GL_LIST_GROUP_SCROLLBAR", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2af2d67226670d265e37963952c8f0350b", null ],
      [ "WID_GL_CREATE_GROUP", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2aeded892ce7dadbbb2f97e71dadee5ea5", null ],
      [ "WID_GL_DELETE_GROUP", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2aa1a9e808db6e3be92f9cb3a505bc4067", null ],
      [ "WID_GL_RENAME_GROUP", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2ab1801b663cda17628c991fdb68468189", null ],
      [ "WID_GL_LIVERY_GROUP", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2ac2a3b61279080c0903837279abc1f173", null ],
      [ "WID_GL_REPLACE_PROTECTION", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a0d6420a58b9e49138ff4a5d381110223", null ],
      [ "WID_GL_INFO", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2af8325a7696b5bda21e1d97212b6ebbb8", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d3/dda/group__widget_8h.js <==
var group__widget_8h =
[
    [ "GroupListWidgets", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2", [
      [ "WID_GL_CAPTION", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a78f7723009fbf2529da1f19aac80540b", null ],
      [ "WID_GL_GROUP_BY_ORDER", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a259c1a4f4cd82e4550d115b75fc395b6", null ],
      [ "WID_GL_GROUP_BY_DROPDOWN", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a5e24523aa32f91606ab42018390eb980", null ],
      [ "WID_GL_SORT_BY_ORDER", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a41128bb986ab09b10e0efe6991932b94", null ],
      [ "WID_GL_SORT_BY_DROPDOWN", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2acc24cc454d4e8db0d41644db6b9f5191", null ],
      [ "WID_GL_LIST_VEHICLE", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2acf25aceb2004acb11b6fa7ce8e1f72b2", null ],
      [ "WID_GL_LIST_VEHICLE_SCROLLBAR", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2abffb4627acd874d536908638fa637711", null ],
      [ "WID_GL_AVAILABLE_VEHICLES", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2aa606555b2be516d207db39dfd4140954", null ],
      [ "WID_GL_MANAGE_VEHICLES_DROPDOWN", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a19363c4697c75ed08a99e2bb934fec53", null ],
      [ "WID_GL_STOP_ALL", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a0609e86d4eeba508ebeaa2aa7e400687", null ],
      [ "WID_GL_START_ALL", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a91fc2a0a141f751551fe4850ff133900", null ],
      [ "WID_GL_ALL_VEHICLES", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a9802f55644a76c6ec5893f35a06300f2", null ],
      [ "WID_GL_DEFAULT_VEHICLES", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2aff47fca9215d425c5276f87c32dec6d7", null ],
      [ "WID_GL_LIST_GROUP", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a0433e02dfa7abb45b0f658bc8396ca60", null ],
      [ "WID_GL_LIST_GROUP_SCROLLBAR", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2af2d67226670d265e37963952c8f0350b", null ],
      [ "WID_GL_CREATE_GROUP", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2aeded892ce7dadbbb2f97e71dadee5ea5", null ],
      [ "WID_GL_DELETE_GROUP", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2aa1a9e808db6e3be92f9cb3a505bc4067", null ],
      [ "WID_GL_RENAME_GROUP", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2ab1801b663cda17628c991fdb68468189", null ],
      [ "WID_GL_LIVERY_GROUP", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2ac2a3b61279080c0903837279abc1f173", null ],
      [ "WID_GL_REPLACE_PROTECTION", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2a0d6420a58b9e49138ff4a5d381110223", null ],
      [ "WID_GL_INFO", "d3/dda/group__widget_8h.html#a7ba5a70d294cfc753f57707e11d965d2af8325a7696b5bda21e1d97212b6ebbb8", null ]
    ] ]
];
